@@ -21,7 +21,7 @@ import gtk, gobject
 import pango
 import datetime as dt
 import time
-import graphics
+import graphics, stuff
 import locale
 
 class Bar(graphics.Sprite):
@@ -106,21 +106,18 @@ class Chart(graphics.Scene):
         self.label_color = self.colors.contrast(fg_color,  80)
 
 
-    def on_mouse_over(self, scene, targets):
-        bar = targets[0]
+    def on_mouse_over(self, scene, bar):
         if bar.key not in self.selected_keys:
             bar.fill = self.get_style().base[gtk.STATE_PRELIGHT].to_string()
 
-    def on_mouse_out(self, scene, targets):
-        bar = targets[0]
+    def on_mouse_out(self, scene, bar):
         if bar.key not in self.selected_keys:
             bar.fill = self.bar_color
 
-    def on_click(self, scene, event, targets):
-        clicked_bar = targets[0]
+    def on_click(self, scene, event, clicked_bar):
+        if not clicked_bar: return
         self.emit("bar-clicked", clicked_bar.key)
 
-
     def plot(self, keys, data):
         self.data = data
 
@@ -142,7 +139,7 @@ class Chart(graphics.Scene):
                 self.tweener.add_tween(bar, normalized=normalized)
             new_bars.append(bar)
 
-            label = graphics.Label(key, size = 8, alignment = pango.ALIGN_RIGHT)
+            label = graphics.Label(stuff.escape_pango(key), size = 8, alignment = pango.ALIGN_RIGHT)
             new_labels.append(label)
 
 
